/*
 * Copyright (C) 2006 INDT
 *  Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*
 */

#ifndef __DMAP_ITEM_H__
#define __DMAP_ITEM_H__

#include <glib.h>
#include <glib-object.h>

G_BEGIN_DECLS

#define TYPE_DMAP_ITEM         (dmap_item_get_type ())
#define DMAP_ITEM(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_DMAP_ITEM, DMAPItem))
#define DMAP_ITEM_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), TYPE_DMAP_ITEM, DMAPItemClass))
#define IS_DMAP_ITEM(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_DMAP_ITEM))
#define IS_DMAP_ITEM_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_DMAP_ITEM))
#define DMAP_ITEM_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_DMAP_ITEM, DMAPItemClass))

typedef struct _DMAPItem        DMAPItem;
typedef struct _DMAPItemClass   DMAPItemClass;
typedef struct _DMAPItemPrivate DMAPItemPrivate;

struct _DMAPItemClass {
    GObjectClass parent;

    /* signals */
    void     (* loaded)         (DMAPItem *self);

    /* callbacks */
    gboolean (* retrieve_items) (DMAPItem *self);
};

struct _DMAPItem {
    GObject parent;

    DMAPItemPrivate *priv;
};

GType         dmap_item_get_type               (void);

gboolean      dmap_item_retrieve_items         (DMAPItem *self,
                                                gboolean force_reload);
const GSList *dmap_item_get_items              (DMAPItem *self);

/* internal */
DMAPItem     *dmap_item_get_parent             (DMAPItem *self);
void          dmap_item_add_child              (DMAPItem *self,
                                                DMAPItem *child);
DMAPItem     *dmap_item_get_child              (DMAPItem *self,
                                                guint id);
void          dmap_item_signal_loaded          (DMAPItem *self);

G_END_DECLS

#endif
