/*
 * Copyright (C) 2006 INDT
 *  Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "dpap-album.h"
#include "dpap-connection.h"
#include "dpap-photo.h"
#include "dmap-structure.h"
#include "dmap-marshal.h"

#include <string.h>

static gboolean dpap_album_retrieve_photos (DMAPItem *self);

G_DEFINE_TYPE (DPAPAlbum, dpap_album, TYPE_DMAP_ITEM)

static void
dpap_album_class_init (DPAPAlbumClass *klass)
{
    DMAPItemClass *dmap_item_class = (DMAPItemClass *) klass;
    dmap_item_class->retrieve_items = dpap_album_retrieve_photos;
}

static void
dpap_album_init (DPAPAlbum *self)
{
}

static void
handle_album_entries (DPAPConnection *connection,
                      guint status,
                      GNode *structure,
                      DMAPItem *self)
{
    GNode *listing_node;
    GNode *node;
    gint i;
    DMAPItem *parent, *photo;

    if (structure == NULL || SOUP_STATUS_IS_SUCCESSFUL (status) == FALSE) {
        return;
    }

    listing_node = dmap_structure_find_node (structure, DMAP_CC_MLCL);
    if (listing_node == NULL) {
        return;
    }

    parent = dmap_item_get_parent (self);
    for (i = 0, node = listing_node->children; node; node = node->next, i++) {
        DMAPStructureItem *item;
        GNode *n2;
        gint item_id = 0;
        const gchar *filename = NULL;
        const gchar *aspect_ratio = NULL;
        gint creation_date = 0;

        item = dmap_structure_find_item (node, DMAP_CC_MIID);
        if (item == NULL) {
            g_debug ("Could not find dmap.itemid item in /databases");
            continue;
        }
        item_id = g_value_get_int (&(item->content));

        if (parent)
            photo = dmap_item_get_child (parent, item_id);
        else
            photo = NULL;

        if (!photo) {
            for (n2 = node->children; n2; n2 = n2->next) {
                DMAPStructureItem *meta_item;

                meta_item = n2->data;

                switch (meta_item->content_code) {
                    case DMAP_CC_MIID:
                        item_id = g_value_get_int (&(meta_item->content));
                        break;
                    case DMAP_CC_PASP:
                        aspect_ratio = g_value_get_string (&(meta_item->content));
                        break;
                    case DMAP_CC_PICD:
                        creation_date = g_value_get_int (&(meta_item->content));
                        break;
                    case DMAP_CC_PIMF:
                        filename = g_value_get_string (&(meta_item->content));
                        break;
                    default:
                        break;
                }
            }

            photo = DMAP_ITEM (g_object_new (TYPE_DPAP_PHOTO,
                    "connection", connection,
                    "id", item_id,
                    "name", filename,
                    "aspect-ratio", aspect_ratio,
                    "creation-date", creation_date,
                    NULL));

            dmap_item_add_child (self, photo);
        }
        else {
            dmap_item_add_child (self, photo);
        }
    }

    dmap_item_signal_loaded (self);
}

static gboolean
dpap_album_retrieve_photos (DMAPItem *self)
{
    DMAPConnection *connection;
    DMAPItem *parent;
    gint id, database_id, session_id;
    gchar *path;
    gboolean ret;

    g_object_get (G_OBJECT (self),
            "id", &id,
            "connection", &connection,
            "parent", &parent,
	    "database-id", &database_id,
	    "session-id", &session_id,
            NULL);

    if (!parent) {
        path = g_strdup_printf ("/databases/%d/items?session-id=%d"
                "&meta=dmap.itemid,dpap.aspectratio,dpap.creationdate,dpap.imagefilename&type=photo", database_id, session_id);
    }
    else {
        path = g_strdup_printf ("/databases/%d/containers/%d/items?session-id=%d"
                "&meta=dmap.itemid,dpap.aspectratio,dpap.creationdate,dpap.imagefilename&type=photo",
		database_id, id, session_id);
        g_object_unref (parent);
    }
    ret = dmap_connection_get (connection, path,
            TRUE, (DMAPResponseHandler) handle_album_entries, self);
    g_free (path);
    g_object_unref (connection);

    return ret;
}
